==> cdk_2.7.1.orig.tar.gz: cdk-cdk-2.7.1/display/renderbasic/src/test/java/org/openscience/cdk/renderer/font/AbstractFontManagerTest.java <==
/* Copyright (C) 2011  Egon Willighagen <egonw@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. All we ask is that proper credit is given for our work,
 * which includes - but is not limited to - adding the above copyright notice to
 * the beginning of your source code files, and to any copyright notice that you
 * may distribute with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.renderer.font;

import org.junit.Assert;
import org.junit.Test;

/**
 * @cdk.module test-renderbasic
 */
public abstract class AbstractFontManagerTest {

    public static AbstractFontManager manager;

    public static void setFontManager(AbstractFontManager fontManager) {
        manager = fontManager;
    }

    @Test
    public void testGetSetFontName() {
        String fontName = "Not-Arial";
        manager.setFontName(fontName);
        Assert.assertEquals(fontName, manager.getFontName());
    }

}

==> cdk_2.9.orig.tar.gz: cdk-cdk-2.9/display/renderbasic/src/test/java/org/openscience/cdk/renderer/font/AbstractFontManagerTest.java <==
/* Copyright (C) 2011  Egon Willighagen <egonw@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. All we ask is that proper credit is given for our work,
 * which includes - but is not limited to - adding the above copyright notice to
 * the beginning of your source code files, and to any copyright notice that you
 * may distribute with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.renderer.font;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

/**
 * @cdk.module test-renderbasic
 */
abstract class AbstractFontManagerTest {

    private static AbstractFontManager manager;

    static void setFontManager(AbstractFontManager fontManager) {
        manager = fontManager;
    }

    @Test
    void testGetSetFontName() {
        String fontName = "Not-Arial";
        manager.setFontName(fontName);
        Assertions.assertEquals(fontName, manager.getFontName());
    }

}
